@@ -1,3 +1,4 @@
+from numpy.lib.type_check import real_if_close
 import cv2
 import numpy as np
 
@@ -9,6 +10,8 @@ class ImageMetrics():
 			img = cv2.imread(img)
 		self.img = img
 		left_img, right_img = self.split_stereo_into_l_r(img)
+		left_img, right_img = self.crop_for_left_vs_right_differences(left_img, 
+		                                                              right_img)
 		self.left_grids = self.create_image_grids(left_img, m=m, n=n)
 		self.right_grids = self.create_image_grids(right_img, m=m, n=n)
 		unequal_grids_msg = "left and right grid sizes do not match!"
